@@ -844,6 +844,16 @@ void LogParam::setWsjtxWidgetState(const QByteArray &state)
     setParam("wsjtx/widgetstate", state.toBase64());
 }
 
+bool LogParam::getWsjtxOutputColorCQSpot()
+{
+    return getParam("wsjtx/output/colorcqspot", false).toBool();
+}
+
+void LogParam::setWsjtxOutputColorCQSpot(bool state)
+{
+    setParam("wsjtx/output/colorcqspot", state);
+}
+
 uint LogParam::getDXCFilterDxccStatus()
 {
     return getParam("dxc/filter/dx/dxccstatus", (DxccStatus::NewEntity | DxccStatus::NewBand |
@@ -1137,12 +1147,12 @@ void LogParam::setMainWindowAlertBeep(bool state)
     setParam("mainwindow/alertbeep", state);
 }
 
-bool LogParam::getMainWindowDarkMode()
+int LogParam::getMainWindowDarkMode()
 {
-    return getParam("mainwindow/darkmode", false).toBool();
+    return getParam("mainwindow/darkmode", 0).toInt();
 }
 
-void LogParam::setMainWindowDarkMode(bool state)
+void LogParam::setMainWindowDarkMode(int state)
 {
     setParam("mainwindow/darkmode", state);
 }
