@@ -5,6 +5,8 @@
 #include <QString>
 #include <QDebug>
 
+#include "core/LogLocale.h"
+
 class Gridsquare
 {
 public:
@@ -14,8 +16,8 @@ public:
     static const QRegularExpression gridRegEx();
     static const QRegularExpression gridVUCCRegEx();
     static const QRegularExpression gridExtRegEx();
-    static double distance2localeUnitDistance(double km, QString &unit);
-    static double localeDistanceCoef();
+    static double distance2localeUnitDistance(double km, QString &unit, const LogLocale &locale);
+    static double localeDistanceCoef(const LogLocale &locale);
 
     bool isValid() const;
     double getLongitude() const {return lon;};
