@@ -15,6 +15,7 @@ class MainWindow;
 }
 
 class QLabel;
+class WsjtxUDPReceiver;
 
 class MainWindow : public QMainWindow {
     Q_OBJECT
@@ -23,9 +24,9 @@ public:
     explicit MainWindow(QWidget* parent = 0);
     ~MainWindow();
 
-    void closeEvent(QCloseEvent* event);
-    void keyReleaseEvent(QKeyEvent *event);
-    void changeEvent(QEvent *event);
+    void closeEvent(QCloseEvent* event) override;
+    void keyReleaseEvent(QKeyEvent *event) override;
+    void changeEvent(QEvent *event) override;
 
     QList<QAction *> getUserDefinedShortcutActionList();
     QStringList getBuiltInStaticShortcutList() const;
@@ -114,9 +115,11 @@ private:
     QActionGroup *dupeGroup;
     QActionGroup *linkExchangeGroup;
     QPushButton *activityButton;
-
+    QMetaObject::Connection alertTextButtonConn;
+    bool firstRun = false;
     void setupActivitiesMenu();
 
+
     void restoreUserDefinedShortcuts();
     void saveUserDefinedShortcuts();
 
@@ -133,6 +136,8 @@ private:
     bool setNativeTheme();
     void setLightTheme();
     void setDarkTheme();
+
+    void showEvent(QShowEvent *event) override;
 };
 
 #endif // QLOG_UI_MAINWINDOW_H
