@@ -44,9 +44,13 @@ public slots:
 
 private slots:
     void sendOnAirState();
+    void freqChanged(double);
 
 private:
 
+    // On AIR pinging to HRDLog [in sec]
+    const int ONAIR_INTERVAL = 60;
+
     void resetRigInfo();
     void saveLastSeenFreq();
     double lastSeenFreq;
