@@ -16,12 +16,10 @@
 #include "core/debug.h"
 #include "models/SqlListModel.h"
 #include "data/Gridsquare.h"
+#include "core/QSOFilterManager.h"
 
 MODULE_IDENTIFICATION("qlog.ui.statisticswidget");
 
-// default statistics interval [in days]
-#define DEFAULT_STAT_RANGE -1
-
 void StatisticsWidget::mainStatChanged(int idx)
 {
      FCT_IDENTIFICATION;
@@ -32,7 +30,6 @@ void StatisticsWidget::mainStatChanged(int idx)
      refreshGraph();
 }
 
-
 void StatisticsWidget::refreshWidget()
 {
     FCT_IDENTIFICATION;
@@ -89,6 +86,9 @@ void StatisticsWidget::refreshGraph()
          genericFilter << " (datetime(start_time) BETWEEN datetime('" + ui->startDateEdit->dateTime().toString("yyyy-MM-dd HH:mm:ss")
                           + "') AND datetime('" + ui->endDateEdit->dateTime().toString("yyyy-MM-dd HH:mm:ss") + "') ) ";
 
+     if ( ui->userFilterCombo->currentIndex() > 0 )
+         genericFilter <<  QSOFilterManager::instance()->getWhereClause(ui->userFilterCombo->currentText());
+
      qCDebug(runtime) << "main " << ui->statTypeMainCombo->currentIndex()
                       << " secondary " << ui->statTypeSecCombo->currentIndex();
 
@@ -250,8 +250,7 @@ void StatisticsWidget::refreshGraph()
          {
          case 0:  // Countries
              stmt = "SELECT translate_to_locale(COALESCE(d.name, c.dxcc)) as dxcc_display, COUNT(1) AS cnt "
-                    "FROM contacts c LEFT JOIN dxcc_entities d ON c.dxcc = d.id "
-                    "WHERE " + genericFilter.join(" AND ") + " "
+                    "FROM ( SELECT * FROM contacts WHERE " + genericFilter.join(" AND ") + ") c LEFT JOIN dxcc_entities_clublog d ON c.dxcc = d.id "
                     "GROUP BY dxcc_display ORDER BY cnt DESC LIMIT 10";
              break;
          case 1:  // Big squares
@@ -279,7 +278,7 @@ void StatisticsWidget::refreshGraph()
          switch ( ui->statTypeSecCombo->currentIndex() )
          {
          case 0:  // Distance
-             QString distCoef = QString::number(Gridsquare::localeDistanceCoef());
+             QString distCoef = QString::number(Gridsquare::localeDistanceCoef(locale));
              stmt = QString("WITH hist AS ( "
                     " SELECT CAST((distance * %1)/500.00 AS INTEGER) * 500 as dist_floor, "
                     " COUNT(1) AS count "
@@ -340,8 +339,8 @@ void StatisticsWidget::refreshGraph()
              break;
          case 2: // ODX
              QString unit;
-             Gridsquare::distance2localeUnitDistance(0, unit);
-             QString distCoef = QString::number(Gridsquare::localeDistanceCoef());
+             Gridsquare::distance2localeUnitDistance(0, unit, locale);
+             QString distCoef = QString::number(Gridsquare::localeDistanceCoef(locale));
              QString sel = QString("SELECT callsign || '<br>' || CAST(ROUND(distance * %1,0) AS INT) || ' %2', gridsquare, my_gridsquare, ").arg(distCoef, unit);
 
              stmt = sel + innerCase + " AS confirmed FROM contacts WHERE "
@@ -400,15 +399,15 @@ void StatisticsWidget::mapLoaded(bool)
     layerControlHandler.restoreLayerControlStates(main_page);
 }
 
-void StatisticsWidget::changeTheme(int theme)
+void StatisticsWidget::changeTheme(int theme, bool isDark)
 {
     FCT_IDENTIFICATION;
 
-    qCDebug(function_parameters) << theme;
+    qCDebug(function_parameters) << theme << isDark;
 
     QString themeJavaScript;
 
-    if ( theme == 1 ) /* dark mode */
+    if (isDark) /* dark mode */
         themeJavaScript = "map.getPanes().tilePane.style.webkitFilter=\"brightness(0.6) invert(1) contrast(3) hue-rotate(200deg) saturate(0.3) brightness(0.9)\";";
     else
         themeJavaScript = "map.getPanes().tilePane.style.webkitFilter=\"\";";
@@ -435,6 +434,8 @@ StatisticsWidget::StatisticsWidget(QWidget *parent) :
     ui->myRigCombo->setModel(new QStringListModel(this));
     ui->myAntennaCombo->setModel(new QStringListModel(this));
     ui->bandCombo->setModel(new QStringListModel(this));
+    ui->userFilterCombo->setModel(QSOFilterManager::QSOFilterModel(tr("No User Filter"),
+                                                                   ui->userFilterCombo));
 
     ui->startDateEdit->setDisplayFormat(locale.formatDateTimeShortWithYYYY());
     ui->startDateEdit->setDate(QDate::currentDate().addDays(DEFAULT_STAT_RANGE));
@@ -480,6 +481,9 @@ bool StatisticsWidget::event(QEvent *event)
         ui->myAntennaCombo->blockSignals(true);
         ui->myAntennaCombo->setCurrentIndex(0);
         ui->myAntennaCombo->blockSignals(false);
+        ui->userFilterCombo->blockSignals(true);
+        ui->userFilterCombo->setCurrentIndex(0);
+        ui->userFilterCombo->blockSignals(false);
         refreshGraph();
     }
     return QWidget::event(event);  // Propagate the event further
@@ -559,7 +563,8 @@ void StatisticsWidget::drawMyLocationsOnMap(QSqlQuery &query)
     if ( query.lastQuery().isEmpty() )
         return;
 
-    QList<QString> locations;
+    QStringList locationIcons;
+    QStringList rawLocationsPoint;
 
     while ( query.next() )
     {
@@ -570,14 +575,16 @@ void StatisticsWidget::drawMyLocationsOnMap(QSqlQuery &query)
         {
             double lat = stationGrid.getLatitude();
             double lon = stationGrid.getLongitude();
-            locations.append(QString("[\"%1\", %2, %3, homeIcon]").arg(loc).arg(lat).arg(lon));
+            locationIcons.append(QString("[\"%1\", %2, %3, homeIcon]").arg(loc).arg(lat).arg(lon));
+            rawLocationsPoint.append(QString("[%1, %2]").arg(lat).arg(lon));
         }
     }
 
     QString javaScript = QString("grids_confirmed = [];"
                                  "grids_worked = [];"
                                  "drawPointsGroup2([%1]);"
-                                 "maidenheadConfWorked.redraw();").arg(locations.join(","));
+                                 "maidenheadConfWorked.redraw();"
+                                 "map.panTo([0, L.latLngBounds([%2]).getCenter().lng]);").arg(locationIcons.join(","), rawLocationsPoint.join(","));
 
     qCDebug(runtime) << javaScript;
 
@@ -608,6 +615,13 @@ void StatisticsWidget::drawPointsOnMap(QSqlQuery &query)
             count++;
             double lat = stationGrid.getLatitude();
             double lon = stationGrid.getLongitude();
+
+            // do not wrap the points
+            double delta = lon - myStationGrid.getLongitude();
+            if ( delta > 180 )
+                lon -= 360;
+            if ( delta < -180 )
+                lon += 360;
             stations.append(QString("[\"%1\", %2, %3, %4]").arg(query.value(0).toString())
                                                            .arg(lat)
                                                            .arg(lon)
@@ -632,9 +646,12 @@ void StatisticsWidget::drawPointsOnMap(QSqlQuery &query)
 
     QString javaScript = QString("grids_confirmed = [];"
                                  "grids_worked = [];"
-                                 "drawPoints([%1]);"
-                                 "drawShortPaths([%2]);"
-                                 "maidenheadConfWorked.redraw();").arg(stations.join(","), shortPaths.join(","));
+                                 "drawPointsBusy([%1], '%2');"
+                                 "drawShortPathsBusy([%3], '%4');"
+                                 "maidenheadConfWorked.redraw();").arg(stations.join(","),
+                                                                       tr("Rendering QSOs..."),
+                                                                       shortPaths.join(","),
+                                                                       tr("Rendering QSOs..."));
 
     qCDebug(runtime) << javaScript;
 
@@ -656,7 +673,7 @@ void StatisticsWidget::drawFilledGridsOnMap(QSqlQuery &query)
 
     while ( query.next() )
     {
-        if ( query.value(2).toInt() > 0 && ! confirmedGrids.contains(query.value(1).toString()) )
+        if ( query.value(3).toInt() > 0 && ! confirmedGrids.contains(query.value(1).toString()) )
             confirmedGrids << QString("\"" + query.value(1).toString() + "\"");
         else
             workedGrids << QString("\"" + query.value(1).toString() + "\"");
@@ -665,8 +682,8 @@ void StatisticsWidget::drawFilledGridsOnMap(QSqlQuery &query)
     QString javaScript = QString("grids_confirmed = [ %1 ]; "
                                  "grids_worked = [ %2 ];"
                                  "mylocations = [];"
-                                 "drawPoints([]);"
-                                 "drawShortPaths([]);"
+                                 "drawPointsBusy([], '');"
+                                 "drawShortPathsBusy([], '');"
                                  "maidenheadConfWorked.redraw();").arg(confirmedGrids.join(","), workedGrids.join(","));
 
     qCDebug(runtime) << javaScript;
@@ -686,6 +703,8 @@ void StatisticsWidget::refreshCombos()
     refreshCombo(ui->myAntennaCombo, QLatin1String("SELECT DISTINCT my_antenna FROM contacts ORDER BY my_antenna"));
     refreshCombo(ui->bandCombo, QLatin1String("SELECT DISTINCT band FROM contacts c, bands b WHERE c.band = b.name ORDER BY b.start_freq;"));
     refreshCombo(ui->myGridCombo, QLatin1String("SELECT DISTINCT UPPER(my_gridsquare) FROM contacts ORDER BY my_gridsquare"));
+    SqlListModel *sqlModel = qobject_cast<SqlListModel*>(ui->userFilterCombo->model());
+    if ( sqlModel ) sqlModel->refresh();
 }
 
 void StatisticsWidget::setSubTypesCombo(int mainTypeIdx)
@@ -735,7 +754,7 @@ void StatisticsWidget::setSubTypesCombo(int mainTypeIdx)
     case 3:
     {
         QString unit;
-        Gridsquare::distance2localeUnitDistance(0, unit);
+        Gridsquare::distance2localeUnitDistance(0, unit, locale);
         ui->statTypeSecCombo->addItem(tr("Distance") + QString(" [%1]").arg(unit));
     }
     break;
