@@ -16,6 +16,7 @@
 #include "data/BandPlan.h"
 #include "core/LogParam.h"
 #include "core/PotaQE.h"
+#include "core/WsjtxUDPReceiver.h"
 
 MODULE_IDENTIFICATION("qlog.ui.wsjtxswidget");
 
@@ -169,6 +170,7 @@ void WsjtxWidget::decodeReceived(WsjtxDecode decode)
 
                 wsjtxTableModel->addOrReplaceEntry(entry);
                 emit filteredCQSpot(entry);
+                emit updatedCQSpot(entry);
             }
         }
     }
@@ -223,21 +225,21 @@ void WsjtxWidget::tableViewDoubleClicked(QModelIndex index)
 
     const QModelIndex &source_index = proxyModel->mapToSource(index);
 
-    const WsjtxEntry &entry = wsjtxTableModel->getEntry(source_index);
+    const WsjtxEntry entry = wsjtxTableModel->getEntry(source_index);
     //emit callsignSelected(entry.callsign, entry.grid); // it is not needed to send this - Qlog receives the change via WSJTX
-    emit reply(entry.decode);
+    emit reply(entry);
 }
 
 void WsjtxWidget::callsignClicked(QString callsign)
 {
     FCT_IDENTIFICATION;
 
-    const WsjtxEntry &entry = wsjtxTableModel->getEntry(callsign);
+    const WsjtxEntry entry = wsjtxTableModel->getEntry(callsign);
     if ( entry.callsign.isEmpty() )
         return;
 
     emit callsignSelected(callsign, entry.grid, entry.decode.id);
-    emit reply(entry.decode);
+    emit reply(entry);
 }
 
 void WsjtxWidget::tableViewClicked(QModelIndex)
